@@ -5,14 +5,19 @@ class ArtistListItem:
     def __init__(self, data : dict):
         self.__item : Item = Item(data)
 
-    def getId(self) -> str | None:
+    def getItem(self): return self.__item
+
+    def getId(self) -> str:
         return self.__item.getId()
 
-    def getName(self) -> str | None:
+    def getName(self) -> str:
         return self.__item.getByName("name")
 
-    def getAlbumCount(self) -> str | None:
+    def getAlbumCount(self) -> str:
         return self.__item.getByName("albumCount")
 
-    def getArtistImageUrl(self) -> str | None:
+    def getCoverArt(self) -> str:
+        return self.__item.getByName("coverArt")
+
+    def getArtistImageUrl(self) -> str:
         return self.__item.getByName("artistImageUrl")
