@@ -6,7 +6,9 @@ class ArtistsInitial:
     def __init__(self, data : dict):
         self.__item : Item = Item(data)
 
-    def getName(self) -> str | None:
+    def getItem(self): return self.__item
+
+    def getName(self) -> str:
         return self.__item.getByName("name")
 
     def getArtistListItems(self) -> list[ArtistListItem]:
