@@ -21,6 +21,12 @@ class DefaultConfiguration(ConfigurationInterface):
     def getPassword(self) -> str:
         return self.__getParameter("SUBSONIC_PASSWORD")
     
+    def getLegacyAuth(self) -> bool:
+        legacy_auth_enabled_str : str = self.__getParameter("SUBSONIC_LEGACYAUTH", "false")
+        if not legacy_auth_enabled_str.lower() in ['true', 'false']: 
+            raise Exception(f"Invalid value for SUBSONIC_LEGACYAUTH [{legacy_auth_enabled_str}]")
+        return legacy_auth_enabled_str == "true"
+
     def getApiVersion(self) -> str:
         return self.__getParameter("SUBSONIC_API_VERSION", libsonic.API_VERSION)
 
