@@ -5,11 +5,13 @@ class Genre:
     def __init__(self, data : dict):
         self.__item : Item = Item(data)
 
-    def getName(self) -> str | None:
+    def getItem(self): return self.__item
+
+    def getName(self) -> str:
         return self.__item.getByName("value")
 
-    def getAlbumCount(self) -> str | None:
+    def getAlbumCount(self) -> str:
         return self.__item.getByName("albumCount")
 
-    def getSongCount(self) -> str | None:
+    def getSongCount(self) -> str:
         return self.__item.getByName("songCount")
\ No newline at end of file
