@@ -3,7 +3,7 @@ class Item:
     def __init__(self, data : dict):
         self.__data = data
 
-    def getData(self) -> dict:
+    def getData(self) -> dict[str, any]:
         return self.__data
 
     def isResponse(self) -> bool:
@@ -14,12 +14,17 @@ class Item:
     def hasName(self, name : str) -> bool:
         return name in self.getData()
 
-    def getByName(self, name : str, defaultValue = None) -> str | None:
+    def getByName(self, name : str, defaultValue = None) -> any:
         return (self.getData()[name]
             if name in self.getData() 
             else defaultValue)
 
-    def getId(self) -> str | None:
+    def getListByName(self, name : str, defaultValue = []) -> list[dict[str, any]]:
+        return (self.getData()[name]
+            if name in self.getData() 
+            else defaultValue)
+    
+    def getId(self) -> str:
         return self.getByName("id")
 
     def getList(self, path : list[str], allowEmpty = True) -> list:
