@@ -5,12 +5,14 @@ from .song import Song
 
 class SearchResult:
 
-    __main_element : str = "searchResult2"
+    __main_element : str = "searchResult3"
 
     def __init__(self, data : dict):
         self.__item : Item = Item(data)
 
-    def getArtists(self) -> list[Song]:
+    def getItem(self): return self.__item
+
+    def getArtists(self) -> list[Artist]:
         return list(map(
             lambda x : Artist(x), 
             self.__item.getList([SearchResult.__main_element, "artist"])))
